@@ -69,5 +69,5 @@ if __name__ == "__main__":
     moviePath = args.m
     subsPath = args.s
     scriptWithTimestamp = sync(moviePath, subsPath)
-    file0 = open("{}.json".format(moviePath), "w+")
+    file0 = open("timestamped.json", "w+")
     json.dump(scriptWithTimestamp, file0, indent=4, ensure_ascii=False)
